package RRD::Cache;

#
# RRD/Function standard cache
# A module should import this one and define GetContent() itself
#
# $Id: Cache.pm,v 1.10 2002/07/06 15:36:52 tommy Exp $
#

use strict;
use Carp;
use Time::HiRes qw(usleep);
use RRD::Config;
use Digest::MD5 qw(md5_hex);

my $TIMEOUT	 = 280;		# default if not specified

sub updated {
    my ($self) = @_;
    return $self->{updated};
}
sub value {
    my ($self) = @_;
    return $self->{value};
}

sub new {
    my ($pkg,%params) = @_;

    my $key = $params{Target} || croak "No Target Specified";
    my $cf = md5_hex("$pkg.$key");

    my $hash = {};
    $hash->{Timeout}   = defined ${$pkg::TIMEOUT} ? ${$pkg::TIMEOUT} : $TIMEOUT;
    $hash->{cachefile} = "$config{cachepath}/$cf";
    $hash->{lockfile}  = "$config{cachepath}/$cf.lock";

    while(my ($k,$v) = each %params) {
        $hash->{$k} = $v;
    }
    
    $hash->{value}     = undef;
    $hash->{updated}   = undef;

    return bless ($hash,$pkg);
}

sub setlock {
    my ($self) = @_;
    open(F,">$self->{lockfile}") || die $!;
    print F $$;
    close F;
}

sub waitlock {
    my ($self) = @_;
    my $max = 0;
    while( -f $self->{lockfile} && $max <= 30000 ) {
        usleep(1000);
        $max++;
    }
}

sub dellock {
    my ($self) = @_;
    unlink($self->{lockfile});
}

#
# store a key and lastupdated time in dbm file
# 
sub store {
    my ($self) = @_;

    my $now    = time();
    my $value  = $self->GetContent || return undef;

    open(F,">".$self->{cachefile}) || croak ("Can't open cache $!");
    print F $value;
    close F;

    $self->{updated} = $now;
    $self->{value} = $value;
}

#
# load a key from dbm file
#
sub load {
    my ($self) = @_;

    my $cf = $self->{cachefile};

    if ( open(F,$cf) ) {
        while(<F>) {
            $self->{value} .= $_;
        }
        close F;

        $self->{updated} = (stat($cf))[9];
        return 1;
    }else{
        return undef;
    }
}

#
# get value associated with this object
# check if not too long in cache, or update and store in cache
#
sub Get {
    my ($self) = @_;

    my $now    = time();
    $self->waitlock();
    $self->setlock();

    if ( not defined $self->{value} or not defined $self->{updated} ) { 
   	if ( ! $self->load ) {
            $self->store;
        }
    }

    if ( ! defined $self->{updated} || 
	$self->{updated} < $now - $self->{Timeout} )
    {	
      	$self->store;
    }
   
    $self->Load;
    
    $self->dellock();
    return $self->{value};
}

1;
