package RRD::Function::carlist;

#
# RRD/Function Cisco CAR lists
# plots committed and dropped graphs
#
# $Id: carlist.pm,v 1.8 2002/12/31 13:17:35 tommy Exp $
#

use RRDs;
use RRD::Template;
use RRD::Cache::SNMP::Uptime;
use SNMP_util;

use vars qw(@ISA $VERSION);
@ISA   = qw(RRD::Template);


sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:input:COUNTER:600:U:U",
	"DS:output:COUNTER:600:U:U",
	"DS:dinput:COUNTER:600:U:U",
	"DS:doutput:COUNTER:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my $cache = new RRD::Cache::SNMP::Uptime( Target=>$self->{Target} );
    $cache->Get;

    # acl nr (1, 2, 3, etc not the access-list nr itself!)
    my $list = $self->{ListNr} || 1;

    if ( $cache->uptime < 300 ) {
        $self->{LastRead} = "in U out U dropin U dropout U";
        RRDs::update($self->{RRD},"N:U:U:U:U");
    }else{
        my $if = $self->ifIndex || return undef;
        my ($in)   = snmpget($self->{Target},
		"1.3.6.1.4.1.9.9.113.1.2.1.1.2.".$if.".1.$list");
        my ($out)  = snmpget($self->{Target},
		"1.3.6.1.4.1.9.9.113.1.2.1.1.2.".$if.".2.$list");
        return unless (defined $in || defined $out);

        my ($din)  = snmpget($self->{Target},
		"1.3.6.1.4.1.9.9.113.1.2.1.1.4.".$if.".1.$list");
        my ($dout) = snmpget($self->{Target},
		"1.3.6.1.4.1.9.9.113.1.2.1.1.4.".$if.".2.$list");
        return unless (defined $din || defined $dout);

	$in = 0 unless $in;
	$out = 0 unless $out;
	$din = 0 unless $din;
	$dout = 0 unless $dout;
	
        $self->{LastRead} = "in $in out $out dropin $din dropout $dout";
        RRDs::update($self->{RRD},"N:$in:$out:$din:$dout");
    }
}

sub Limiter {
    my ($self) = @_;
    my $max = $self->{Limit};

    if ( $max ) {
        return ("CDEF:val1=input,8,* ",
                "CDEF:val2=output,8,* ",
                "CDEF:val3=dinput,8,* ",
                "CDEF:val4=doutput,8,* ",
		"CDEF:inputb=val1,0,$max,LIMIT",
		"CDEF:outputb=val2,0,$max,LIMIT",
		"CDEF:dinputb=val3,0,$max,LIMIT",
		"CDEF:doutputb=val4,0,$max,LIMIT",
	       );
    }else{
        return (
		"CDEF:inputb=input,8,*",
		"CDEF:outputb=output,8,*",
		"CDEF:dinputb=dinput,8,*",
		"CDEF:doutputb=doutput,8,*",
	       );
    }
}


sub Graph {
    my ($self,$file,$time) = @_;

    my @limit = $self->Limiter;

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v Bandwidth", 
	"-s ".$time,
	"DEF:input=".$self->{RRD}.":input:AVERAGE",
	"DEF:output=".$self->{RRD}.":output:AVERAGE",
	"DEF:dinput=".$self->{RRD}.":dinput:AVERAGE",
	"DEF:doutput=".$self->{RRD}.":doutput:AVERAGE",
	@limit,
        "LINE2:inputb#00CC00:Incoming Traffic",
        "GPRINT:inputb:LAST:Current\\:%8.3lf %sbps  ",
        "GPRINT:inputb:MAX:Max\\:%8.3lf %sbps  ",
        "GPRINT:inputb:AVERAGE:Average\\:%8.3lf %sbps\\l",
        "LINE2:outputb#0000FF:Outgoing Traffic",
        "GPRINT:outputb:LAST:Current\\:%8.3lf %sbps  ",
        "GPRINT:outputb:MAX:Max\\:%8.3lf %sbps  ",
        "GPRINT:outputb:AVERAGE:Average\\:%8.3lf %sbps\\l",
        "LINE2:dinputb#FF0000:Dropped Incoming",
        "GPRINT:dinputb:LAST:Current\\:%8.3lf %sbps  ",
        "GPRINT:dinputb:MAX:Max\\:%8.3lf %sbps  ",
        "GPRINT:dinputb:AVERAGE:Average\\:%8.3lf %sbps\\l",
        "LINE2:doutputb#EEEE00:Dropped Outgoing",
        "GPRINT:doutputb:LAST:Current\\:%8.3lf %sbps  ",
        "GPRINT:doutputb:MAX:Max\\:%8.3lf %sbps  ",
        "GPRINT:doutputb:AVERAGE:Average\\:%8.3lf %sbps\\l",
	$self->Defaults,
    );
}

1;
