package RRD::Function::ciscocpu;

#
# RRD/Function Cisco CPU load meter
#
# $Id: ciscocpu.pm,v 1.6 2003/04/17 14:21:15 tommy Exp $
#

use RRDs;
use RRD::Template;
use SNMP_util;

use vars qw(@ISA $VERSION);
@ISA   = qw(RRD::Template);


sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:cpu1:GAUGE:600:U:U",
	"DS:cpu2:GAUGE:600:U:U",
	"DS:cpu3:GAUGE:600:U:U",
	"DS:cpu4:GAUGE:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;
 
    my @cpu = (0,0,0,0);
    my $oid = ".1.3.6.1.4.1.9.9.109.1.1.1.1.5.1";

    #actually read 3 values when 4 reserved in rrd
    my $up = 0;
    for (my $i=0; $i<3; $i++) {
        @res = snmpgetnext($self->{Target},$oid);
	if ( defined $res[0] ) {
          ($oid,$val) = split (":",$res[0],2);
          $cpu[$i] = $val;
	  $up++;
	}else{
	  $cpu[$i] = "U";
	}
    }
    return undef if ! $up;

    $self->{LastRead} = join(":",@cpu);
    RRDs::update($self->{RRD}, "N:".join(":",@cpu) );
}

sub Limiter {
    my ($self) = @_;
    my $max = $self->{Limit};
                                                                                
    if ( $max ) {
        return (
                "CDEF:cpu1=val1,0,$max,LIMIT",
                "CDEF:cpu2=val2,0,$max,LIMIT",
                "CDEF:cpu3=val3,0,$max,LIMIT",
                "CDEF:cpu4=val4,0,$max,LIMIT",
               );
    }else{
        return ( 
                "CDEF:cpu1=val1",
                "CDEF:cpu2=val2",
                "CDEF:cpu3=val3",
                "CDEF:cpu4=val4",
	       );
    }
}

sub Graph {
    my ($self,$file,$time) = @_;

    my @limit    = $self->Limiter;

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v CPU Load", 
	"-s ".$time,
	"DEF:val1=".$self->{RRD}.":cpu1:AVERAGE",
	"DEF:val2=".$self->{RRD}.":cpu2:AVERAGE",
	"DEF:val3=".$self->{RRD}.":cpu3:AVERAGE",
	"DEF:val4=".$self->{RRD}.":cpu4:AVERAGE",
	@limit,
        "LINE2:cpu1#00CC00:CPU 1",
        "GPRINT:cpu1:LAST:Current\\: %2.0lf %%  ",
        "GPRINT:cpu1:MAX:Max\\: %2.0lf %%  ",
        "GPRINT:cpu1:AVERAGE:Average\\: %2.0lf %%\\l",
        "LINE2:cpu2#0000FF:CPU 2",
        "GPRINT:cpu2:LAST:Current\\: %2.0lf %%  ",
        "GPRINT:cpu2:MAX:Max\\: %2.0lf %%  ",
        "GPRINT:cpu2:AVERAGE:Average\\: %2.0lf %%\\l",
        "LINE2:cpu3#EEEE00:CPU 3",
        "GPRINT:cpu3:LAST:Current\\: %2.0lf %%  ",
        "GPRINT:cpu3:MAX:Max\\: %2.0lf %%  ",
        "GPRINT:cpu3:AVERAGE:Average\\: %2.0lf %%\\l",
        "LINE2:cpu4#FF0000:CPU 4",
        "GPRINT:cpu4:LAST:Current\\: %2.0lf %%  ",
        "GPRINT:cpu4:MAX:Max\\: %2.0lf %%  ",
        "GPRINT:cpu4:AVERAGE:Average\\: %2.0lf %%\\l",
	$self->Defaults,
    );
}

1;
