package RRD::Function::lincpu;

#
# RRD/Function Linux 2.4 Aggregate CPU counter
#
# old changelog:
# 0.02 initial
# 0.03 limit 200, dual cpu
#
# $Id: lincpu.pm,v 1.5 2002/09/26 17:11:48 tommy Exp $
#

use RRDs;
use RRD::Template;
use RRD::Cache::SNMP::Uptime;
use SNMP_util;

use vars qw(@ISA $VERSION);
@ISA   = qw(RRD::Template);


sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:user:COUNTER:600:U:U",
	"DS:nice:COUNTER:600:U:U",
	"DS:system:COUNTER:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my $cache = new RRD::Cache::SNMP::Uptime( Target=>$self->{Target} );
    $cache->Get;
    if ( $cache->uptime < 300 ) {
        $self->{LastRead} = "user U nice U system U";
        RRDs::update($self->{RRD},"N:U:U:U");
    }else{
        my ($user) = snmpget($self->{Target},".1.3.6.1.4.1.2021.11.50.0"); 
        return unless defined $user;
        my ($nice) = snmpget($self->{Target},".1.3.6.1.4.1.2021.11.51.0"); 
        return unless defined $nice;
        my ($system) = snmpget($self->{Target},".1.3.6.1.4.1.2021.11.52.0"); 
        return unless defined $system;

        $self->{LastRead} = "user $user system $system nice $nice";
        RRDs::update($self->{RRD}, "N:$user:$nice:$system" );
    }
}

sub Graph {
    my ($self,$file,$time) = @_;

    RRDs::graph($self->{OutDir}."/$file.png",
        $self->DefaultOpts,
	"-v CPU Load", 
	"-s ".$time,
	"DEF:v1=".$self->{RRD}.":user:AVERAGE",
	"DEF:v2=".$self->{RRD}.":nice:AVERAGE",
	"DEF:v3=".$self->{RRD}.":system:AVERAGE",
        "CDEF:val1=v1,0,200,LIMIT",
        "CDEF:val2=v2,0,200,LIMIT",
        "CDEF:val3=v3,0,200,LIMIT",
        "LINE2:val1#00CC00:User  ",
        "GPRINT:val1:LAST:Current\\: %.0lf %%  ",
        "GPRINT:val1:MAX:Max\\: %.0lf %%  ",
        "GPRINT:val1:AVERAGE:Average\\: %.0lf %%\\l",
        "LINE2:val2#0000FF:Nice  ",
        "GPRINT:val2:LAST:Current\\: %.0lf %%  ",
        "GPRINT:val2:MAX:Max\\: %.0lf %%  ",
        "GPRINT:val2:AVERAGE:Average\\: %.0lf %%\\l",
        "LINE2:val3#FF0000:System",
        "GPRINT:val3:LAST:Current\\: %.0lf %%  ",
        "GPRINT:val3:MAX:Max\\: %.0lf %%  ",
        "GPRINT:val3:AVERAGE:Average\\: %.0lf %%\\l",
	$self->Defaults,
    );
}

1;
