package RRD::Function::lindiskio;

#
# Linux Disk Sectors/sec statistics
# uses the ProcStat cache module
# put the procstat.sh binary on the remote server by telnet/inetd something like:
# procstat        stream  tcp     nowait  root    /usr/sbin/tcpd  /usr/sbin/procstat.sh
# procstat is portnumber xx used by "Target: xx@host" as specified in /etc/services
#
# $Id: lindiskio.pm,v 1.2 2003/06/21 17:15:46 tommy Exp $
#

use RRDs;
use RRD::Template;
use RRD::Cache::ProcStat;

use Data::Dumper;

use vars qw(@ISA $VERSION @EXPORT @colors);
@EXPORT   = qw(@REQUIRED);
@ISA      = qw(RRD::Template);
@REQUIRED = qw(Disk);

sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:read:COUNTER:600:U:U",
	"DS:write:COUNTER:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my $cache = new RRD::Cache::ProcStat( Target => $self->{Target} );
    $cache->Get;

    my $d = $self->{Disk};
    my $update = "N:". $cache->rsect($d) .":". $cache->wsect($d);

    $self->{LastRead} = $update;
    RRDs::update($self->{RRD}, $update);
}

sub Graph {
    my ($self,$file,$time) = @_;

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v Sectors", 
	"-s ".$time,
	"DEF:rr=".$self->{RRD}.":read:AVERAGE",
	"DEF:ww=".$self->{RRD}.":write:AVERAGE",
        "LINE2:rr#00CC00:Read Sectors   ",
        "GPRINT:rr:LAST:Current\\: %.0lf   ",
        "GPRINT:rr:MAX:Max\\: %.0lf   ",
        "GPRINT:rr:AVERAGE:Average\\: %.0lf \\l",
        "LINE2:ww#FF0000:Write Sectors  ",
        "GPRINT:ww:LAST:Current\\: %.0lf   ",
        "GPRINT:ww:MAX:Max\\: %.0lf   ",
        "GPRINT:ww:AVERAGE:Average\\: %.0lf \\l",
	$self->Defaults,
    );
}

1;
