package RRD::Function::linmem;

#
# RRD/Function Linux 2.4 memory counter
#
# $Id: linmem.pm,v 1.5 2002/09/26 17:11:48 tommy Exp $
#

use RRDs;
use RRD::Template;
use SNMP_util;

use vars qw(@ISA $VERSION);
@ISA   = qw(RRD::Template);


sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:real:GAUGE:600:U:U",
	"DS:buffer:GAUGE:600:U:U",
	"DS:cache:GAUGE:600:U:U",
	"DS:swap:GAUGE:600:U:U",
	"DS:free:GAUGE:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my ($total)  = snmpget($self->{Target},".1.3.6.1.4.1.2021.4.5.0");
    return unless defined $total;
    my ($free)   = snmpget($self->{Target},".1.3.6.1.4.1.2021.4.6.0");
    return unless defined $free;
    my ($buffer) = snmpget($self->{Target},".1.3.6.1.4.1.2021.4.14.0");
    return unless defined $buffer;
    my ($cache)  = snmpget($self->{Target},".1.3.6.1.4.1.2021.4.15.0");
    return unless defined $cache;
    my ($swap)   = snmpget($self->{Target},".1.3.6.1.2.1.25.2.3.1.6.102");
    return unless defined $swap;

    my $real = $total - $free - $buffer - $cache;

    $self->{LastRead} = "real $real buffer $buffer cache $cache swap $swap";
    RRDs::update($self->{RRD}, "N:$real:$buffer:$cache:$swap:$free" );
}

sub Graph {
    my ($self,$file,$time) = @_;

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v Memory Usage", 
	"-s ".$time,
	"DEF:def1=".$self->{RRD}.":real:AVERAGE",
	"DEF:def2=".$self->{RRD}.":buffer:AVERAGE",
	"DEF:def3=".$self->{RRD}.":cache:AVERAGE",
	"DEF:def4=".$self->{RRD}.":swap:AVERAGE",
	"DEF:def5=".$self->{RRD}.":free:AVERAGE",
        "CDEF:val1=def1,1024,*",
        "CDEF:val2=def2,1024,*",
        "CDEF:val3=def3,1024,*",
        "CDEF:val4=def4,1024,*",
        "CDEF:val5=def5,1024,*",
        "LINE2:val1#00CC00:Real  ",
        "GPRINT:val1:LAST:Current\\:%6.1lf %sb  ",
        "GPRINT:val1:MAX:Max\\:%6.1lf %sb  ",
        "GPRINT:val1:AVERAGE:Average\\:%6.1lf %sb\\l",
        "LINE2:val2#0000FF:Buffer",
        "GPRINT:val2:LAST:Current\\:%6.1lf %sb  ",
        "GPRINT:val2:MAX:Max\\:%6.1lf %sb  ",
        "GPRINT:val2:AVERAGE:Average\\:%6.1lf %sb\\l",
        "LINE2:val3#FF0000:Cache ",
        "GPRINT:val3:LAST:Current\\:%6.1lf %sb  ",
        "GPRINT:val3:MAX:Max\\:%6.1lf %sb  ",
        "GPRINT:val3:AVERAGE:Average\\:%6.1lf %sb\\l",
        "LINE2:val4#EEEE00:Swap  ",
        "GPRINT:val4:LAST:Current\\:%6.1lf %sb  ",
        "GPRINT:val4:MAX:Max\\:%6.1lf %sb  ",
        "GPRINT:val4:AVERAGE:Average\\:%6.1lf %sb\\l",
        "LINE2:val5#AAAAAA:Free  ",
        "GPRINT:val5:LAST:Current\\:%6.1lf %sb  ",
        "GPRINT:val5:MAX:Max\\:%6.1lf %sb  ",
        "GPRINT:val5:AVERAGE:Average\\:%6.1lf %sb\\l",
	$self->Defaults,
    );
}

1;
