package RRD::Function::port;

#
# RRD/Function standard port grapher
# usable on most unices and network devices
# using standard snmp oids
#
# $Id: port.pm,v 1.8 2002/10/18 22:17:56 tommy Exp $
#

use RRDs;
use RRD::Template;
use RRD::Cache::SNMP::Uptime;

use SNMP_util;

# we export @REQUIRED because this module is acting as a template
use vars qw(@ISA @EXPORT @REQUIRED);
@ISA      = qw(RRD::Template);
@EXPORT	  = qw(@REQUIRED);
@REQUIRED = qw(Interface);

sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
        "DS:input:COUNTER:600:U:U",
        "DS:output:COUNTER:600:U:U",
        @stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my $cache = new RRD::Cache::SNMP::Uptime( Target=>$self->{Target} );
    $cache->Get || return undef;

    if ( $cache->uptime < 300 ) {
        $self->{LastRead} = "in U out U";
        RRDs::update($self->{RRD},"N:U:U");
    }else{
        my $if = $self->ifIndex || return undef;
        my ($in)  = snmpget($self->{Target},"1.3.6.1.2.1.2.2.1.10.".$if);
        return unless defined $in;
        my ($out) = snmpget($self->{Target},"1.3.6.1.2.1.2.2.1.16.".$if);
        return unless defined $out;

        $self->{LastRead} = "in $in out $out";
        RRDs::update($self->{RRD},"N:$in:$out");
    }
}


sub Limiter {
    my ($self) = @_;
    my $max = $self->{Limit};

    if ( $max ) {
        return ("CDEF:inb=input,8,* ",
                "CDEF:outb=output,8,* ",
                "CDEF:inbits=inb,0,".$max.",LIMIT ",
                "CDEF:outbits=outb,0,".$max.",LIMIT " );
    }else{
        return ("CDEF:inbits=input,8,* ",
                "CDEF:outbits=output,8,* " );
    }
}

sub Graph {
    my ($self,$file,$time) = @_;

    my @limit    = $self->Limiter;

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v Bandwidth", 
	"-s ".$time,
	"DEF:input=".$self->{RRD}.":input:AVERAGE",
	"DEF:output=".$self->{RRD}.":output:AVERAGE",
	@limit,
    	"AREA:inbits#00CC00:".$self->{In},
        "GPRINT:inbits:LAST:Current\\: %8.3lf %sbps  ",
        "GPRINT:inbits:MAX:Max\\: %8.3lf %sbps  ",
        "GPRINT:inbits:AVERAGE:Average\\: %8.3lf %sbps\\l",
        "LINE2:outbits#0000FF:".$self->{Out},
        "GPRINT:outbits:LAST:Current\\: %8.3lf %sbps  ",
        "GPRINT:outbits:MAX:Max\\: %8.3lf %sbps  ",
        "GPRINT:outbits:AVERAGE:Average\\: %8.3lf %sbps\\l",
	$self->Defaults,
    );
}


1;
