package RRD::Function::rtstats;

#
# RRD/Function RT Queue Statistics generator
# Put the required stats collector script on
# your rt server in inetd.conf
# use something like:
# /usr/local/rt2/bin/rt --summary %id6%status8%owner10%queue16%created25%updated25 --limit-status=new --limit-status=open
#
# $Id: rtstats.pm,v 1.1 2003/01/15 10:07:40 tommy Exp $
#

use RRDs;
use RRD::Template;
use RRD::Cache::RT;

use Data::Dumper;

use vars qw(@ISA $VERSION @EXPORT @colors);
@EXPORT   = qw(@REQUIRED);
@ISA      = qw(RRD::Template);
@REQUIRED = qw(Queue Status Users);

@colors = qw(ff0000 00ff00 0000ff ffff00 00ffff 000000 880000 008800 000088 888800 008888 888888);

sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
	"DS:u1:GAUGE:600:U:U",
	"DS:u2:GAUGE:600:U:U",
	"DS:u3:GAUGE:600:U:U",
	"DS:u4:GAUGE:600:U:U",
	"DS:u5:GAUGE:600:U:U",
	"DS:u6:GAUGE:600:U:U",
	"DS:u7:GAUGE:600:U:U",
	"DS:u8:GAUGE:600:U:U",
	"DS:u9:GAUGE:600:U:U",
	"DS:u10:GAUGE:600:U:U",
	"DS:u11:GAUGE:600:U:U",
	"DS:u12:GAUGE:600:U:U",
	@stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my $cache = new RRD::Cache::RT( Target => $self->{Target} );
    $cache->Get;

    my $q = $self->{Queue};

    my $i=0;
    my $update = "N:";
    for(split(/[\s\,]/, $self->{Users})) {
        my $usr = $_;
  	my $val = 0;
	if ( $self->{Status} eq "open" ) {
            $val = $cache->get_open_own_q($usr, $q);
	}elsif ( $self->{Status} eq "new" ) {
            $val = $cache->get_new_own_q($usr, $q);
	}else{
      	    die("This module does not support status ".$self->{Status});
	}
	$update .= "$val:";
        $i++;
    }
    for (;$i<12;$i++) {
        $update .= "U:";
    }
    chop $update;

    $self->{LastRead} = $update;
    RRDs::update($self->{RRD}, $update );
}

sub Graph {
    my ($self,$file,$time) = @_;
    my @arr;
    my $i=1;
    my @c = @colors;

    for(split(/[\s\,]/, $self->{Users})) {
        my $usr = $_;
  	my $val = 0;
	my $c = shift @c;
        push(@arr,sprintf("LINE2:v%d#%s:%-8s ",$i,$c,$usr));
        push(@arr,"GPRINT:v".$i.":LAST:Current\\: %.0lf   ");
        push(@arr,"GPRINT:v".$i.":MAX:Max\\: %.0lf   ");
        push(@arr,"GPRINT:v".$i.":AVERAGE:Average\\: %.0lf \\l");
	$i++;
    }

    RRDs::graph($self->{OutDir}."/$file.png",
    	$self->DefaultOpts,
	"-v Tickets", 
	"-s ".$time,
	"DEF:v1=".$self->{RRD}.":u1:AVERAGE",
	"DEF:v2=".$self->{RRD}.":u2:AVERAGE",
	"DEF:v3=".$self->{RRD}.":u3:AVERAGE",
	"DEF:v4=".$self->{RRD}.":u4:AVERAGE",
	"DEF:v5=".$self->{RRD}.":u5:AVERAGE",
	"DEF:v6=".$self->{RRD}.":u6:AVERAGE",
	"DEF:v7=".$self->{RRD}.":u7:AVERAGE",
	"DEF:v8=".$self->{RRD}.":u8:AVERAGE",
	"DEF:v9=".$self->{RRD}.":u9:AVERAGE",
	"DEF:v10=".$self->{RRD}.":u10:AVERAGE",
	"DEF:v11=".$self->{RRD}.":u11:AVERAGE",
	"DEF:v12=".$self->{RRD}.":u12:AVERAGE",
	@arr,
	$self->Defaults,
    );
}

1;
