package RRD::Function::tcpres;
#
# RRD/Function Generic Response time
# Retrieve something over tcp connection and measure time.
# Target: port@host
# Send: HEAD / HTTP/1.0\n (for example, or dont specify wait for 1 line of data)
#
# $Id: tcpres.pm,v 1.1 2002/10/25 23:11:57 tommy Exp $
#

use RRDs;
use RRD::Template;
use Net::Telnet;
use Time::HiRes qw(gettimeofday tv_interval);

use vars qw(@ISA $VERSION);
@ISA   = qw(RRD::Template);

sub CreateDB {
    my ($self) = @_;

    RRDs::create($self->{RRD},
        "DS:time:GAUGE:600:U:U",
        @stdrra,
    );
}

sub Update {
    my ($self) = @_;

    my ($port,$ip) = split("@",$self->{Target});

    # measure start time
    my @t0 = gettimeofday();

    my $telnet = new Net::Telnet( Host => $ip, 
    				  Port => $port, 
				  Timeout => 10, 
				  Errmode => 'return' 
				);
    if ( ! $telnet ) { return undef; }

    if ( $self->{Send} ) {
        $self->{Send} =~ s/\\n/\n/g; 
        $telnet->print($self->{Send}) || return undef;
    }
    my $val = $telnet->getline || return undef;

    # measure end time
    my @t1 = gettimeofday();

    my $elapsed = tv_interval ( \@t0, \@t1 );
    $telnet->close;

    $self->{LastRead} = $elapsed;
    RRDs::update($self->{RRD}, "N:$elapsed" );
}

sub Graph {
    my ($self,$file,$time) = @_;

    RRDs::graph($self->{OutDir}."/$file.png",
        $self->DefaultOpts,
        "-v Response Time",
        "-s ".$time,
        "DEF:time=".$self->{RRD}.":time:AVERAGE",
        "LINE2:time#FF0000",
        "GPRINT:time:LAST:Current\\: %7.1lf %ss ",
        "GPRINT:time:MAX:Max\\: %7.1lf %ss ",
        "GPRINT:time:AVERAGE:Average\\: %7.1lf %ss\\l",
        $self->Defaults,
    );
}

1;
