package RRD::Template;

#
# RRD/Function standard template
#
# $Id: Template.pm,v 1.12 2003/04/28 21:50:47 tommy Exp $
#

use RRDs;
use Carp;
use Exporter;
use POSIX qw(strftime);
use RRD::Config;
use RRD::Cache::SNMP::ifIndex;
use RRD::Info qw(LogEntry);


use vars   qw(@ISA $VERSION @EXPORT @stdrra @lastupd @stdopts $intfile $ifDescrOid);
@ISA     = qw(Exporter);
@EXPORT  = qw(@stdrra @lastupd @stdopts lastupd);


@stdrra     = ( "RRA:AVERAGE:0.5:1:600",
                "RRA:AVERAGE:0.5:6:700",
                "RRA:AVERAGE:0.5:24:775",
                "RRA:AVERAGE:0.5:288:797",
                "RRA:MAX:0.5:1:600",
                "RRA:MAX:0.5:6:700",
                "RRA:MAX:0.5:24:775",
                "RRA:MAX:0.5:288:797",
              );

@stdopts    = ( "-aPNG", "-l 0", "-z" );


sub lastupd {
  return ( "COMMENT:Last Updated: ".strftime("%d-%m-%G %H:%M",localtime())."\\l" );
}

sub new {
    my ($pkg,$info) = @_;
    return bless { %{$info} }, $pkg;
}

sub hrule {
    my ($self) = @_;
    return if ! $self->{HRule};
    return ("HRULE:".$self->{HRule}."#ff0000");
}

sub Defaults {
    my ($self) = @_;
    return ( lastupd(), $self->hrule );
}

sub DefaultOpts {
    my ($self) = @_;
    return "-aPNG", "-l0 ", "--lazy", "-w".$self->{Width}, "-h".$self->{Height}, "-t".$self->{Description};
}

sub ifIndex { 
    my ($self) = @_;

    if ( ! $self->{updated} || $self->{updated} < time() - $config{timeout} || ! $self->{ifIndex} ) {

        my $oidstr = ${ref($self)."::ifDescrOid"} || undef;

        my $ifdx = new RRD::Cache::SNMP::ifIndex(
		 Target     => $self->{Target}, 	
    	         ifDescrOid => $oidstr,
	         Timeout	=> $config{timeout},
	);
        $ifdx->Get;
        $self->{updated} = $ifdx->updated;
        $self->{ifIndex} = $ifdx->ifIndex( $self->{Interface} )
	    || LogEntry($ifdx->errmsg . " in $self->{NFO}"); 
    }

    return $self->{ifIndex};
}

1;
