package RRD::Web;

# 
# rrdbrowse Web functions
#
# $Id: Web.pm,v 1.13 2002/12/31 13:18:48 tommy Exp $
#

use strict;
use Carp;
use Data::Dumper;
use DirHandle;
use RRD::Info;
use RRD::Config;
use Image::Magick;
use Exporter;

use vars     qw(@ISA @EXPORT_OK);
@ISA	   = qw(Exporter RRD::Info);
@EXPORT_OK = qw(
	ShowImage
	ShowThumb
	GetDirHash
);

sub ShowImage {
    my ($nfo,$time) = @_;
 
    my $info  = new RRD::Info("$config{nfopath}/$nfo");
    my $image = "$config{pngpath}/$info->{Workdir}/$info->{Directory}/$time.png";
    
    open(F,$image) || croak "Cant open image ($image) $!";
      local $/;
      $_=<F>;
      print;
    close F;

    undef $info;
}

sub ShowThumb {
    my ($nfo,$time) = @_;
 
    my $info  = new RRD::Info("$config{nfopath}/$nfo");
    my $image = "$config{pngpath}/$info->{Workdir}/$info->{Directory}/$time.png";
   
    my $thumb = Image::Magick->new;
    $thumb->read($image);
    $thumb->Scale(width=>360,height=>140);

    my ($blob) = $thumb->ImageToBlob;
    print $blob;

    undef $thumb;
}

#
# get hash with hash to files and directories
# return hash $return
#
sub GetDirHash {
    my ($dir,$basepath) = @_;

    if ( ! $dir ) { $dir = ""; }
    die "Wrong path ($dir)\n" if $dir =~ m/\.\./g;

    my @dirs = ();
    my @fils = ();

    my $return = { dirs => {}, files => {} };

    if ( $dir ne "" ) {
        my $dir2 = $dir;
        $dir2 =~ s/\/\w+$//;
        $return->{dirs}{$dir2} = "/..";
    }

    my $newdir = "$basepath/$dir";

    my $dh = new DirHandle($newdir)  || croak "$!";
    while(my $f = $dh->read) {
        next if ($f =~ m/^\.|^\.\./ );

        if ( -d "$newdir/$f" ) {
            $return->{dirs}{"$dir/$f"} = "$dir/$f";

        }elsif ( $f =~ m/\.nf.$/ ) {
            my $info = new RRD::Info("$config{nfopath}/$dir/$f");
            $return->{files}{"$dir/$f"} = $info->{Description};
            undef $info;

        }elsif ( $f =~ m/\.pag$/ ) {
            my $file = "$config{pagepath}/$dir/$f";
            my $title = $dir;
            if(open(F,$file)){$title=<F>;chop $title;close(F);}
            $return->{files}{"$dir/$f"} = $title;

        }else{
            # no dir, no .nfo file, display nothing
        }
    }
    $dh->close;

    return $return;
}

1;
